@@ -10,14 +10,14 @@ class ServerBase:
             Dathost server ID.
         """
 
-        self.context = context
+        self._context = context
         self.server_id = server_id
 
 
 class FileBase:
     def __init__(self, context: object,
                  server_id: str, file_path: str) -> None:
-        self.context = context
+        self._context = context
         self.server_id = server_id
         self.file_path = file_path
 
@@ -27,5 +27,5 @@ class BackupBase:
                  backup_name: str) -> None:
 
         self.backup_name = backup_name
-        self.context = context
+        self._context = context
         self.server_id = server_id
